//+------------------------------------------------------------------+
//|                                                 GT BB SINWIN.mq4 |
//|                      Copyright  2010, MetaQuotes Software Corp. |
//|                             http://www.mql4.com/ru/users/rustein |
//+------------------------------------------------------------------+
#define MAGIC  131313
//-------------------------------------------------------------------+
extern int    StopLoss          = 34;
extern int    TakeProfit        = 89;
extern int    Slippage          = 3;
//-------------------------------------------------------------------+
extern double Lots              = 0.01;
extern int    MaxLossTrade      = 6;
//-------------------------------------------------------------------+
extern double LotMulti=2;
//+------------------------------------------------------------------+
extern int    BBPeriod          = 20;
extern int    BBDeviation       = 2;
extern int    BBPrice           = 0; // 0=Close,1=Open,2=High,3=Low,4=Median,5=Typical,6=Weighted
//-------------------------------------------------------------------+
extern int    BBShift           = 1; // 0=Current Bar, 1=Last Bar...
//-------------------------------------------------------------------+
extern bool   MAFilter          = true;
//-------------------------------------------------------------------+
extern int    FastMA            = 21;
extern int    FastMAMethod      = 0; // 0=SMA,1=EMA,2=SSMA,3=LWMA
extern int    FastMAPrice       = 0; // 0=Close,1=Open,2=High,3=Low,4=Median,5=Typical,6=Weighted
//-------------------------------------------------------------------+
extern int    SlowMA            = 34;
extern int    SlowMAMethod      = 0; // 0=SMA,1=EMA,2=SSMA,3=LWMA
extern int    SlowMAPrice       = 0; // 0=Close,1=Open,2=High,3=Low,4=Median,5=Typical,6=Weighted
//-------------------------------------------------------------------+
extern int    MAShift           = 1;
//-------------------------------------------------------------------+
//+------------------------------------------------------------------+
//| Calculate open positions                                         |
//+------------------------------------------------------------------+
int CalculateCurrentOrders(string symbol)
  {
   int buys=0,sells=0;
//----
   for(int i=0;i<OrdersTotal();i++)
     {
      if(OrderSelect(i,SELECT_BY_POS,MODE_TRADES)==false) break;
      if(OrderSymbol()==Symbol() && OrderMagicNumber()==MAGIC)
        {
         if(OrderType()==OP_BUY)  buys++;
         if(OrderType()==OP_SELL) sells++;
        }
     }
//---- return orders volume
   if(buys>0) return(buys);
   else       return(-sells);
  }
//+------------------------------------------------------------------+
//| Calculate optimal lot size                                       |
//+------------------------------------------------------------------+
double LotsOptimized()
  {
   double lot=Lots;
   int    orders=HistoryTotal();     // history orders total
   int    losses=0;                  // number of losses orders without a break
//---- select lot size
//---- calcuulate number of losses orders without a break
   if(OrdersTotal()>=0)
     {
      for(int i=orders-1;i>=0;i--)
        {
         if(OrderSelect(i,SELECT_BY_POS,MODE_HISTORY)==false) { Print("Error in history!"); break; }
         if(OrderSymbol()!=Symbol() || OrderType()>OP_SELL) continue;
         //----
         if(OrderProfit()>0) break;
         if(OrderProfit()<0) losses++;
        }
      lot= (Lots * MathPow(LotMulti,losses));
      if(losses>MaxLossTrade) lot=Lots;
     }
//---- return lot size
   if(lot<Lots) lot=Lots;
   return(lot);
  }
//+------------------------------------------------------------------+
//| Check for open order conditions                                  |
//+------------------------------------------------------------------+
void CheckForOpen()
  {
   double ma;
   int    res;
//---- go trading only for first tiks of new bar
   if(Volume[0]>1) return;
//--------------------------------------------------------------------+
      double BBup = iBands(NULL,0,BBPeriod,BBDeviation,0,BBPrice, MODE_UPPER,BBShift);
      double BBlo = iBands(NULL,0,BBPeriod,BBDeviation,0,BBPrice, MODE_LOWER,BBShift);
      
      double maFast = iMA(NULL,0,FastMA,0,FastMAMethod,FastMAPrice,MAShift);
      double maSlow = iMA(NULL,0,SlowMA,0,SlowMAMethod,SlowMAPrice,MAShift);
//--------------------------------------------------------------------+
//---- buy conditions
     if(High[BBShift] > BBup && MAFilter == false)
     {
      res = OrderSend(Symbol(),OP_BUY,LotsOptimized(),Ask,Slippage,Ask-(StopLoss*Point),Ask+(TakeProfit*Point),"GT SINWIN",MAGIC,0,Green);
      return;       
     }
//---- buy conditions
     if(High[BBShift] > BBup && MAFilter == true && maFast > maSlow)
     {
      res = OrderSend(Symbol(),OP_BUY,LotsOptimized(),Ask,Slippage,Ask-(StopLoss*Point),Ask+(TakeProfit*Point),"GT SINWIN",MAGIC,0,Green);
      return;       
     }
//---- sell conditions
     if(Low[BBShift] < BBlo && MAFilter == false)  
     {
      res = OrderSend(Symbol(),OP_SELL,LotsOptimized(),Bid,Slippage,Bid+(StopLoss*Point),Bid-(TakeProfit*Point),"GT SINWIN",MAGIC,0,Red);
      return; 
     }
//---- sell conditions
     if(Low[BBShift] < BBlo && MAFilter == true &&  maFast < maSlow)  
     {
      res = OrderSend(Symbol(),OP_SELL,LotsOptimized(),Bid,Slippage,Bid+(StopLoss*Point),Bid-(TakeProfit*Point),"GT SINWIN",MAGIC,0,Red);
      return; 
     }
//----
  }
//+------------------------------------------------------------------+
//| Start function                                                   |
//+------------------------------------------------------------------+
void start()
  { 
//---- check for history and trading
   if(Bars<100 || IsTradeAllowed()==false) return;
//---- calculate open orders by current symbol
   if(CalculateCurrentOrders(Symbol())==0) CheckForOpen();
  }
//+------------------------------------------------------------------+
//|---------------------------// END //------------------------------|
//+------------------------------------------------------------------+